aboutsummaryrefslogtreecommitdiffstats
path: root/lib/AdminPanel/Privileges.pm
diff options
context:
space:
mode:
Diffstat (limited to 'lib/AdminPanel/Privileges.pm')
-rw-r--r--lib/AdminPanel/Privileges.pm10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/AdminPanel/Privileges.pm b/lib/AdminPanel/Privileges.pm
index 4352c5c..5833900 100644
--- a/lib/AdminPanel/Privileges.pm
+++ b/lib/AdminPanel/Privileges.pm
@@ -1,22 +1,22 @@
# vim: set et ts=4 sw=4:
# Copyright 2012-2015 Matteo Pasotti
#
-# This file is part of AdminPanel
+# This file is part of ManaTools
#
# AdminPanel is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# AdminPanel is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with AdminPanel. If not, see <http://www.gnu.org/licenses/>.
+# along with ManaTools. If not, see <http://www.gnu.org/licenses/>.
-package AdminPanel::Privileges;
+package ManaTools::Privileges;
use strict;
use warnings;
@@ -1,22 +1,22 @@
#
-# AdminPanel is free software: you can redistribute it and/or modify
+# ManaTools is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
@@ -1,22 +1,22 @@
# (at your option) any later version.
#
-# AdminPanel is distributed in the hope that it will be useful,
+# ManaTools is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the